@@ -9,20 +9,19 @@ from pytype import load_pytd
 from pytype import vm
 from pytype.pytd import pytd
 from pytype.pytd import pytd_utils
+from pytype.tests import test_base
 import six
 
 import unittest
 
 
-class ConvertTest(unittest.TestCase):
-
-  PYTHON_VERSION = (2, 7)
+class ConvertTest(test_base.UnitTest):
 
   def setUp(self):
-    super(ConvertTest, self).setUp()
-    options = config.Options.create(python_version=self.PYTHON_VERSION)
+    super().setUp()
+    options = config.Options.create(python_version=self.python_version)
     self._vm = vm.VirtualMachine(
-        errors.ErrorLog(), options, load_pytd.Loader(None, self.PYTHON_VERSION))
+        errors.ErrorLog(), options, load_pytd.Loader(None, self.python_version))
 
   def _load_ast(self, name, src):
     with file_utils.Tempdir() as d:
@@ -32,7 +31,7 @@ class ConvertTest(unittest.TestCase):
 
   def _convert_class(self, name, ast):
     return self._vm.convert.constant_to_value(
-        ast.Lookup(name), {}, self._vm.root_cfg_node)
+        ast.Lookup(name), {}, self._vm.root_node)
 
   def test_convert_metaclass(self):
     ast = self._load_ast("a", """
@@ -73,14 +72,14 @@ class ConvertTest(unittest.TestCase):
       x = ...  # type: Dict[str]
     """)
     val = self._vm.convert.constant_to_value(
-        ast.Lookup("a.x").type, {}, self._vm.root_cfg_node)
+        ast.Lookup("a.x").type, {}, self._vm.root_node)
     self.assertIs(val.formal_type_parameters[abstract_utils.K],
                   self._vm.convert.str_type)
     self.assertIs(val.formal_type_parameters[abstract_utils.V],
                   self._vm.convert.unsolvable)
 
   def test_convert_long(self):
-    val = self._vm.convert.constant_to_value(2**64, {}, self._vm.root_cfg_node)
+    val = self._vm.convert.constant_to_value(2**64, {}, self._vm.root_node)
     self.assertIs(val, self._vm.convert.primitive_class_instances[int])
 
   def test_heterogeneous_tuple(self):
@@ -89,9 +88,9 @@ class ConvertTest(unittest.TestCase):
       x = ...  # type: Tuple[str, int]
     """)
     x = ast.Lookup("a.x").type
-    cls = self._vm.convert.constant_to_value(x, {}, self._vm.root_cfg_node)
+    cls = self._vm.convert.constant_to_value(x, {}, self._vm.root_node)
     instance = self._vm.convert.constant_to_value(
-        abstract_utils.AsInstance(x), {}, self._vm.root_cfg_node)
+        abstract_utils.AsInstance(x), {}, self._vm.root_node)
     self.assertIsInstance(cls, abstract.TupleClass)
     six.assertCountEqual(self, cls.formal_type_parameters.items(),
                          [(0, self._vm.convert.str_type),
@@ -111,19 +110,18 @@ class ConvertTest(unittest.TestCase):
          self._vm.convert.primitive_class_instances[int]])
 
   def test_build_bool(self):
-    any_bool = self._vm.convert.build_bool(self._vm.root_cfg_node, None)
-    t_bool = self._vm.convert.build_bool(self._vm.root_cfg_node, True)
-    f_bool = self._vm.convert.build_bool(self._vm.root_cfg_node, False)
+    any_bool = self._vm.convert.build_bool(self._vm.root_node, None)
+    t_bool = self._vm.convert.build_bool(self._vm.root_node, True)
+    f_bool = self._vm.convert.build_bool(self._vm.root_node, False)
     self.assertEqual(any_bool.data,
                      [self._vm.convert.primitive_class_instances[bool]])
     self.assertEqual(t_bool.data, [self._vm.convert.true])
     self.assertEqual(f_bool.data, [self._vm.convert.false])
 
   def test_boolean_constants(self):
-    true = self._vm.convert.constant_to_value(True, {}, self._vm.root_cfg_node)
+    true = self._vm.convert.constant_to_value(True, {}, self._vm.root_node)
     self.assertEqual(true, self._vm.convert.true)
-    false = self._vm.convert.constant_to_value(
-        False, {}, self._vm.root_cfg_node)
+    false = self._vm.convert.constant_to_value(False, {}, self._vm.root_node)
     self.assertEqual(false, self._vm.convert.false)
 
   def test_callable_with_args(self):
@@ -132,9 +130,9 @@ class ConvertTest(unittest.TestCase):
       x = ...  # type: Callable[[int, bool], str]
     """)
     x = ast.Lookup("a.x").type
-    cls = self._vm.convert.constant_to_value(x, {}, self._vm.root_cfg_node)
+    cls = self._vm.convert.constant_to_value(x, {}, self._vm.root_node)
     instance = self._vm.convert.constant_to_value(
-        abstract_utils.AsInstance(x), {}, self._vm.root_cfg_node)
+        abstract_utils.AsInstance(x), {}, self._vm.root_node)
     self.assertIsInstance(cls, abstract.CallableClass)
     six.assertCountEqual(
         self,
@@ -163,9 +161,9 @@ class ConvertTest(unittest.TestCase):
       x = ... # type: Callable[[], ...]
     """)
     x = ast.Lookup("a.x").type
-    cls = self._vm.convert.constant_to_value(x, {}, self._vm.root_cfg_node)
+    cls = self._vm.convert.constant_to_value(x, {}, self._vm.root_node)
     instance = self._vm.convert.constant_to_value(
-        abstract_utils.AsInstance(x), {}, self._vm.root_cfg_node)
+        abstract_utils.AsInstance(x), {}, self._vm.root_node)
     self.assertIsInstance(
         cls.get_formal_type_parameter(abstract_utils.ARGS), abstract.Empty)
     self.assertEqual(abstract_utils.get_atomic_value(
@@ -178,9 +176,9 @@ class ConvertTest(unittest.TestCase):
       x = ...  # type: Callable[..., int]
     """)
     x = ast.Lookup("a.x").type
-    cls = self._vm.convert.constant_to_value(x, {}, self._vm.root_cfg_node)
+    cls = self._vm.convert.constant_to_value(x, {}, self._vm.root_node)
     instance = self._vm.convert.constant_to_value(
-        abstract_utils.AsInstance(x), {}, self._vm.root_cfg_node)
+        abstract_utils.AsInstance(x), {}, self._vm.root_node)
     self.assertIsInstance(cls, abstract.ParameterizedClass)
     six.assertCountEqual(self, cls.formal_type_parameters.items(),
                          [(abstract_utils.ARGS, self._vm.convert.unsolvable),
@@ -201,7 +199,7 @@ class ConvertTest(unittest.TestCase):
       def f(*args: int): ...
     """)
     f = self._vm.convert.constant_to_value(
-        ast.Lookup("a.f"), {}, self._vm.root_cfg_node)
+        ast.Lookup("a.f"), {}, self._vm.root_node)
     sig, = f.signatures
     annot = sig.signature.annotations["args"]
     self.assertEqual(pytd_utils.Print(annot.get_instance_type()),
@@ -212,7 +210,7 @@ class ConvertTest(unittest.TestCase):
       def f(**kwargs: int): ...
     """)
     f = self._vm.convert.constant_to_value(
-        ast.Lookup("a.f"), {}, self._vm.root_cfg_node)
+        ast.Lookup("a.f"), {}, self._vm.root_node)
     sig, = f.signatures
     annot = sig.signature.annotations["kwargs"]
     self.assertEqual(pytd_utils.Print(annot.get_instance_type()),
@@ -223,7 +221,7 @@ class ConvertTest(unittest.TestCase):
       x = ...  # type: dict
     """)
     x = ast.Lookup("a.x").type
-    cls = self._vm.convert.constant_to_value(x, {}, self._vm.root_cfg_node)
+    cls = self._vm.convert.constant_to_value(x, {}, self._vm.root_node)
     self.assertListEqual([v.name for v in cls.mro],
                          ["dict", "Dict", "MutableMapping", "Mapping", "Sized",
                           "Iterable", "Container", "Generic", "Protocol",
@@ -235,12 +233,12 @@ class ConvertTest(unittest.TestCase):
       y = ...  # type: dict[str, int]
     """)
     x = ast.Lookup("a.x").type
-    tup = self._vm.convert.constant_to_value(x, {}, self._vm.root_cfg_node)
+    tup = self._vm.convert.constant_to_value(x, {}, self._vm.root_node)
     widened_tup = self._vm.convert.widen_type(tup)
     self.assertEqual(pytd_utils.Print(widened_tup.get_instance_type()),
                      "Iterable[int]")
     y = ast.Lookup("a.y").type
-    dct = self._vm.convert.constant_to_value(y, {}, self._vm.root_cfg_node)
+    dct = self._vm.convert.constant_to_value(y, {}, self._vm.root_node)
     widened_dct = self._vm.convert.widen_type(dct)
     self.assertEqual(pytd_utils.Print(widened_dct.get_instance_type()),
                      "Mapping[str, int]")
@@ -250,9 +248,9 @@ class ConvertTest(unittest.TestCase):
     f_pytd = pytd.Function(
         name="f", signatures=(sig,), kind=pytd.METHOD,
         flags=pytd.Function.abstract_flag(True))
-    f = self._vm.convert.constant_to_value(f_pytd, {}, self._vm.root_cfg_node)
+    f = self._vm.convert.constant_to_value(f_pytd, {}, self._vm.root_node)
     self.assertTrue(f.is_abstract)
-    f_out = f.to_pytd_def(self._vm.root_cfg_node, f.name)
+    f_out = f.to_pytd_def(self._vm.root_node, f.name)
     self.assertTrue(f_out.is_abstract)
 
   def test_class_abstract_method(self):
@@ -262,7 +260,7 @@ class ConvertTest(unittest.TestCase):
         def f(self) -> int: ...
     """)
     cls = self._vm.convert.constant_to_value(
-        ast.Lookup("a.A"), {}, self._vm.root_cfg_node)
+        ast.Lookup("a.A"), {}, self._vm.root_node)
     six.assertCountEqual(self, cls.abstract_methods, {"f"})
 
   def test_class_inherited_abstract_method(self):
@@ -273,7 +271,7 @@ class ConvertTest(unittest.TestCase):
       class B(A): ...
     """)
     cls = self._vm.convert.constant_to_value(
-        ast.Lookup("a.B"), {}, self._vm.root_cfg_node)
+        ast.Lookup("a.B"), {}, self._vm.root_node)
     six.assertCountEqual(self, cls.abstract_methods, {"f"})
 
   def test_class_override_abstract_method(self):
@@ -285,7 +283,7 @@ class ConvertTest(unittest.TestCase):
         def f(self) -> bool: ...
     """)
     cls = self._vm.convert.constant_to_value(
-        ast.Lookup("a.B"), {}, self._vm.root_cfg_node)
+        ast.Lookup("a.B"), {}, self._vm.root_node)
     self.assertFalse(cls.abstract_methods)
 
   def test_class_override_abstract_method_still_abstract(self):
@@ -298,7 +296,7 @@ class ConvertTest(unittest.TestCase):
         def f(self) -> bool: ...
     """)
     cls = self._vm.convert.constant_to_value(
-        ast.Lookup("a.B"), {}, self._vm.root_cfg_node)
+        ast.Lookup("a.B"), {}, self._vm.root_node)
     six.assertCountEqual(self, cls.abstract_methods, {"f"})
 
   def test_parameterized_class_abstract_method(self):
@@ -308,7 +306,7 @@ class ConvertTest(unittest.TestCase):
         def f(self) -> int: ...
     """)
     cls = self._vm.convert.constant_to_value(
-        ast.Lookup("a.A"), {}, self._vm.root_cfg_node)
+        ast.Lookup("a.A"), {}, self._vm.root_node)
     parameterized_cls = abstract.ParameterizedClass(cls, {}, self._vm)
     six.assertCountEqual(self, parameterized_cls.abstract_methods, {"f"})
 
@@ -319,7 +317,7 @@ class ConvertTest(unittest.TestCase):
         v: ClassVar[int]
     """)
     pyval = ast.Lookup("a.X").Lookup("v").type
-    v = self._vm.convert.constant_to_value(pyval, {}, self._vm.root_cfg_node)
+    v = self._vm.convert.constant_to_value(pyval, {}, self._vm.root_node)
     self.assertEqual(v, self._vm.convert.int_type)
 
   def test_classvar_instance(self):
@@ -330,7 +328,7 @@ class ConvertTest(unittest.TestCase):
     """)
     pyval = ast.Lookup("a.X").Lookup("v").type
     v = self._vm.convert.constant_to_value(
-        abstract_utils.AsInstance(pyval), {}, self._vm.root_cfg_node)
+        abstract_utils.AsInstance(pyval), {}, self._vm.root_node)
     self.assertEqual(v, self._vm.convert.primitive_class_instances[int])
 
   def test_constant_name(self):
