@@ -23,7 +23,7 @@ class FrameState(utils.VirtualMachineWeakrefMixin):
   __slots__ = ["block_stack", "data_stack", "node", "exception", "why"]
 
   def __init__(self, data_stack, block_stack, node, vm, exception, why):
-    super(FrameState, self).__init__(vm)
+    super().__init__(vm)
     self.data_stack = data_stack
     self.block_stack = block_stack
     self.node = node
@@ -185,7 +185,7 @@ class FrameState(utils.VirtualMachineWeakrefMixin):
                       self.why)
 
 
-class SimpleFrame(object):
+class SimpleFrame:
   """A lightweight placeholder frame.
 
   A frame used when we need a placeholder on the stack, e.g., to imitate a
@@ -239,7 +239,7 @@ class Frame(utils.VirtualMachineWeakrefMixin):
       node: The current CFG graph node.
       vm: The owning virtual machine.
       f_code: The code object to execute in this frame.
-      f_globals: The global context to execute in as a SimpleAbstractValue as
+      f_globals: The global context to execute in as a SimpleValue as
         used by TypegraphVirtualMachine.
       f_locals: Local variables. Will be modified if callargs is passed.
       f_back: The frame above this one on the stack.
@@ -250,7 +250,7 @@ class Frame(utils.VirtualMachineWeakrefMixin):
     Raises:
       NameError: If we can't resolve any references into the outer frame.
     """
-    super(Frame, self).__init__(vm)
+    super().__init__(vm)
     assert isinstance(f_globals, abstract.LazyConcreteDict)
     assert isinstance(f_locals, abstract.LazyConcreteDict)
     self.node = node
@@ -264,7 +264,7 @@ class Frame(utils.VirtualMachineWeakrefMixin):
       self.f_builtins = f_back.f_builtins
     else:
       _, bltin = self.vm.attribute_handler.get_attribute(
-          self.vm.root_cfg_node, f_globals, "__builtins__")
+          self.vm.root_node, f_globals, "__builtins__")
       builtins_pu, = bltin.bindings
       self.f_builtins = builtins_pu.data
     self.f_lineno = f_code.co_firstlineno
@@ -326,7 +326,7 @@ class Frame(utils.VirtualMachineWeakrefMixin):
     )
 
 
-class Condition(object):
+class Condition:
   """Represents a condition due to if-splitting.
 
   Properties:
